"""
This contains the suite of tests run over the Factory object in order
to guarantee is robustness.

Many of the tests utilise the factories in the example subpackage. If you
plan to contribute fixes or additional functionality you should ensure that
all of the pre-existing tests pass as well as having test coverage for any
additional changes.
"""
